# Generated by Django 4.2.2 on 2023-08-29 10:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("artd_partner", "0002_headquarter_partner_slug"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="headquarter",
            name="partner_slug",
        ),
        migrations.AddField(
            model_name="partner",
            name="partner_slug",
            field=models.SlugField(
                default="",
                help_text="Slug of headquarter",
                max_length=150,
                unique=True,
                verbose_name="slug",
            ),
        ),
    ]
